class NoResultFoundError(Exception):
    pass


class UnsupportedUpdateError(TypeError):
    pass


class DownloadFailedError(Exception):
    pass
